@@ -13,6 +13,7 @@ from .sensor_config import SensorConfig
 from .validation_error import ValidationError, ValidationResult, ValidationWarning
 
 
+@utils.no_dynamic_member_creation
 class SessionConfig:
     """Session configuration
 
@@ -133,7 +134,7 @@ class SessionConfig:
         else:
             self._update_rate = utils.validate_float(value, min_value=0.0, inclusive=False)
 
-    def _assert_not_extended(self):
+    def _assert_not_extended(self) -> None:
         if self.extended:
             raise RuntimeError("This operation requires SessionConfig not to be extended.")
 
@@ -292,7 +293,7 @@ def _unsqueeze_groups(
     raise ValueError
 
 
-def _validate_groups_structure(groups):
+def _validate_groups_structure(groups: list[dict[int, SensorConfig]]) -> None:
     if len(groups) < 1:
         raise ValueError
 
