@@ -2,6 +2,7 @@
 # All rights reserved
 
 from .client import Client
+from .exploration_client import ExplorationClient
 from .exploration_protocol import (
     ExplorationProtocol,
     ExplorationProtocolError,
@@ -9,3 +10,4 @@ from .exploration_protocol import (
     get_exploration_protocol,
 )
 from .links import AdaptedSerialLink, AdaptedSocketLink, AdaptedUSBLink
+from .message import Message, MessageT
