@@ -7,7 +7,10 @@ import json
 from typing import Any, Optional
 
 from acconeer.exptool.a121._core.entities import PRF, IdleState, SensorCalibration, SessionConfig
-from acconeer.exptool.a121._core.mediators import CommunicationProtocol, Message
+from acconeer.exptool.a121._core.peripherals.communication.communication_protocol import (
+    CommunicationProtocol,
+)
+from acconeer.exptool.a121._core.peripherals.communication.message import Message
 from acconeer.exptool.a121._core.utils import map_over_extended_structure
 
 from . import messages
