@@ -12,7 +12,7 @@ import qtawesome as qta
 from PySide6.QtWidgets import QPushButton, QVBoxLayout, QWidget
 
 from acconeer.exptool import a121
-from acconeer.exptool.a121.algo._base import ConfigT
+from acconeer.exptool.a121.algo._base import ProcessorConfigT
 from acconeer.exptool.a121.algo._plugins._a121 import A121ViewPluginBase
 from acconeer.exptool.app.new import (
     BUTTON_ICON_COLOR,
@@ -20,6 +20,7 @@ from acconeer.exptool.app.new import (
     AttrsConfigEditor,
     GeneralMessage,
     GridGroupBox,
+    MiscErrorView,
     PidgetFactoryMapping,
     PluginState,
     SessionConfigEditor,
@@ -33,10 +34,9 @@ from .backend_plugin import ProcessorBackendPluginSharedState
 log = logging.getLogger(__name__)
 
 
-class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
+class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ProcessorConfigT]):
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
         super().__init__(app_model=app_model, view_widget=view_widget)
-        self.app_model = app_model
 
         sticky_layout = QVBoxLayout()
         sticky_layout.setContentsMargins(0, 0, 0, 0)
@@ -53,8 +53,8 @@ class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
             "Stop",
             self.sticky_widget,
         )
-        self.start_button.clicked.connect(self._send_start_requests)
-        self.stop_button.clicked.connect(self._send_stop_requests)
+        self.start_button.clicked.connect(self._send_start_request)
+        self.stop_button.clicked.connect(self._send_stop_request)
 
         self.start_button.setShortcut("space")
         self.start_button.setToolTip("Starts the session.\n\nShortcut: Space")
@@ -72,7 +72,7 @@ class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
         self.perf_calc_view = SmartPerfCalcView(parent=self.scrolly_widget)
         scrolly_layout.addWidget(self.perf_calc_view)
 
-        self.processor_config_editor = AttrsConfigEditor[ConfigT](
+        self.processor_config_editor = AttrsConfigEditor[ProcessorConfigT](
             title="Processor parameters",
             factory_mapping=self.get_pidget_mapping(),
             parent=self.scrolly_widget,
@@ -80,6 +80,9 @@ class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
         self.processor_config_editor.sig_update.connect(self._on_processor_config_update)
         scrolly_layout.addWidget(self.processor_config_editor)
 
+        self.misc_error_view = MiscErrorView(self.scrolly_widget)
+        scrolly_layout.addWidget(self.misc_error_view)
+
         self.session_config_editor = SessionConfigEditor(
             self.supports_multiple_subsweeps(), self.scrolly_widget
         )
@@ -94,23 +97,11 @@ class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
             "update_session_config", {"session_config": session_config}
         )
 
-    def _on_processor_config_update(self, processor_config: ConfigT) -> None:
+    def _on_processor_config_update(self, processor_config: ProcessorConfigT) -> None:
         self.app_model.put_backend_plugin_task(
             "update_processor_config", {"processor_config": processor_config}
         )
 
-    def _send_start_requests(self) -> None:
-        self.app_model.put_backend_plugin_task(
-            "start_session",
-            {"with_recorder": self.app_model.recording_enabled},
-            on_error=self.app_model.emit_error,
-        )
-        self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
-
-    def _send_stop_requests(self) -> None:
-        self.app_model.put_backend_plugin_task("stop_session", on_error=self.app_model.emit_error)
-        self.app_model.set_plugin_state(PluginState.LOADED_STOPPING)
-
     def handle_message(self, message: GeneralMessage) -> None:
         if message.name == "sync":
             log.debug(f"{type(self).__name__} syncing")
@@ -142,6 +133,22 @@ class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
                 backend_plugin_state.metadata,
             )
 
+            if backend_plugin_state.processor_config is not None:
+                results = (
+                    backend_plugin_state.processor_config._collect_validation_results(
+                        backend_plugin_state.session_config
+                    )
+                    + backend_plugin_state.session_config._collect_validation_results()
+                )
+
+                not_handled = self.session_config_editor.handle_validation_results(results)
+
+                not_handled = self.processor_config_editor.handle_validation_results(not_handled)
+
+                not_handled = self.misc_error_view.handle_validation_results(not_handled)
+
+                assert not_handled == []
+
     def on_app_model_update(self, app_model: AppModel) -> None:
         self.session_config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
         self.processor_config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
@@ -151,7 +158,12 @@ class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
         )
 
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
-        self.session_config_editor.update_available_sensor_list(app_model._a121_server_info)
+
+        if app_model.backend_plugin_state:
+            self.session_config_editor.set_selected_sensor(
+                app_model.backend_plugin_state.session_config.sensor_id,
+                self.app_model.connected_sensors,
+            )
 
     @classmethod
     def supports_multiple_subsweeps(self) -> bool:
@@ -164,5 +176,5 @@ class ProcessorViewPluginBase(A121ViewPluginBase, Generic[ConfigT]):
 
     @classmethod
     @abc.abstractmethod
-    def get_processor_config_cls(cls) -> Type[ConfigT]:
+    def get_processor_config_cls(cls) -> Type[ProcessorConfigT]:
         pass
