@@ -8,6 +8,7 @@ from enum import Enum, auto
 from typing import Any, Callable, Dict, Mapping, Optional
 
 import attrs
+import h5py
 import numpy as np
 import qtawesome as qta
 
@@ -29,10 +30,9 @@ from acconeer.exptool.a121.algo.distance import (
     DetectorConfig,
     DetectorContext,
     DetectorResult,
-    PeakSortingMethod,
-    ThresholdMethod,
 )
 from acconeer.exptool.a121.algo.distance._detector import _load_algo_data
+from acconeer.exptool.a121.algo.distance._detector_plugin import ViewPlugin as DistanceViewPlugin
 from acconeer.exptool.app.new import (
     BUTTON_ICON_COLOR,
     AppModel,
@@ -128,20 +128,12 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
         self.restore_defaults()
 
-    @is_task
-    def load_from_cache(self) -> None:
-        try:
-            with self.h5_cache_file() as f:
-                self.shared_state.config = DetectorConfig.from_json(f["config"][()])
-                self.shared_state.bilateration_config = ProcessorConfig.from_json(
-                    f["bilateration_config"][()]
-                )
-                self.shared_state.context = DetectorContext.from_h5(f["context"])
-        except FileNotFoundError:
-            pass
-
-        self._sync_sensor_ids()
-        self.broadcast(sync=True)
+    def _load_from_cache(self, file: h5py.File) -> None:
+        self.shared_state.config = DetectorConfig.from_json(file["config"][()])
+        self.shared_state.bilateration_config = ProcessorConfig.from_json(
+            file["bilateration_config"][()]
+        )
+        self.shared_state.context = DetectorContext.from_h5(file["context"])
 
     @is_task
     def restore_defaults(self) -> None:
@@ -152,6 +144,10 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         if self.client is not None:
             sensor_ids = self.client.server_info.connected_sensors
 
+            # Try to use the sensor ids from the last calibration
+            if self.shared_state.context.sensor_ids:
+                self.shared_state.sensor_ids = self.shared_state.context.sensor_ids
+
             for i in range(len(self.shared_state.sensor_ids)):
                 if len(sensor_ids) > 0 and self.shared_state.sensor_ids[i] not in sensor_ids:
                     self.shared_state.sensor_ids[i] = sensor_ids[0]
@@ -178,19 +174,13 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self.shared_state.bilateration_config = preset_config.bilateration_config
         self.broadcast(sync=True)
 
-    def teardown(self) -> None:
-        try:
-            with self.h5_cache_file(write=True) as f:
-                _create_h5_string_dataset(f, "config", self.shared_state.config.to_json())
-                _create_h5_string_dataset(
-                    f, "bilateration_config", self.shared_state.bilateration_config.to_json()
-                )
-                context_group = f.create_group("context")
-                self.shared_state.context.to_h5(context_group)
-        except Exception:
-            log.warning("Detector could not write to cache")
-
-        self.detach_client()
+    def save_to_cache(self, file: h5py.File) -> None:
+        _create_h5_string_dataset(file, "config", self.shared_state.config.to_json())
+        _create_h5_string_dataset(
+            file, "bilateration_config", self.shared_state.bilateration_config.to_json()
+        )
+        context_group = file.create_group("context")
+        self.shared_state.context.to_h5(context_group)
 
     def load_from_record_setup(self, *, record: a121.H5Record) -> None:
         algo_group = record.get_algo_group(self.key)
@@ -213,17 +203,17 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         else:
             algo_group = None
 
-        self._detector_instance.start(
-            recorder,
-            _algo_group=algo_group,
-        )
-
         self._processor_instance = Processor(
             session_config=self._detector_instance.session_config,
             processor_config=self.shared_state.bilateration_config,
             sensor_ids=self.shared_state.sensor_ids,
         )
 
+        self._detector_instance.start(
+            recorder,
+            _algo_group=algo_group,
+        )
+
         self.callback(
             GeneralMessage(
                 name="setup",
@@ -466,7 +456,6 @@ class ViewPlugin(DetectorViewPluginBase):
 
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
         super().__init__(app_model=app_model, view_widget=view_widget)
-        self.app_model = app_model
 
         sticky_layout = QVBoxLayout()
         sticky_layout.setContentsMargins(0, 0, 0, 0)
@@ -571,83 +560,18 @@ class ViewPlugin(DetectorViewPluginBase):
 
     @classmethod
     def _get_pidget_mapping(cls) -> PidgetFactoryMapping:
-        return {
-            "start_m": pidgets.FloatParameterWidgetFactory(
-                name_label_text="Range start",
-                suffix=" m",
-                decimals=3,
-            ),
-            "end_m": pidgets.FloatParameterWidgetFactory(
-                name_label_text="Range end",
-                suffix=" m",
-                decimals=3,
-            ),
-            "max_step_length": pidgets.OptionalIntParameterWidgetFactory(
-                name_label_text="Max step length",
-                checkbox_label_text="Set",
-                limits=(1, None),
-                init_set_value=12,
-            ),
-            "max_profile": pidgets.EnumParameterWidgetFactory(
-                name_label_text="Max profile",
-                enum_type=a121.Profile,
-                label_mapping={
-                    a121.Profile.PROFILE_1: "1 (shortest)",
-                    a121.Profile.PROFILE_2: "2",
-                    a121.Profile.PROFILE_3: "3",
-                    a121.Profile.PROFILE_4: "4",
-                    a121.Profile.PROFILE_5: "5 (longest)",
-                },
-            ),
-            "num_frames_in_recorded_threshold": pidgets.IntParameterWidgetFactory(
-                name_label_text="Num frames in rec. thr.",
-                limits=(1, None),
-            ),
-            "threshold_method": pidgets.EnumParameterWidgetFactory(
-                name_label_text="Threshold method",
-                enum_type=ThresholdMethod,
-                label_mapping={
-                    ThresholdMethod.CFAR: "CFAR",
-                    ThresholdMethod.FIXED: "Fixed",
-                    ThresholdMethod.RECORDED: "Recorded",
-                },
-            ),
-            "peaksorting_method": pidgets.EnumParameterWidgetFactory(
-                name_label_text="Peak sorting method",
-                enum_type=PeakSortingMethod,
-                label_mapping={
-                    PeakSortingMethod.CLOSEST: "Closest",
-                    PeakSortingMethod.HIGHEST_RCS: "Highest RCS",
-                },
-            ),
-            "fixed_threshold_value": pidgets.FloatParameterWidgetFactory(
-                name_label_text="Fixed threshold value",
-                decimals=1,
-                limits=(0, None),
-            ),
-            "threshold_sensitivity": pidgets.FloatSliderParameterWidgetFactory(
-                name_label_text="Threshold sensitivity",
-                decimals=2,
-                limits=(0, 1),
-                show_limit_values=False,
-            ),
-            "signal_quality": pidgets.FloatSliderParameterWidgetFactory(
-                name_label_text="Signal quality",
-                decimals=1,
-                limits=(-10, 35),
-                show_limit_values=False,
-                limit_texts=("Less power", "Higher quality"),
-            ),
-            "update_rate": pidgets.FloatParameterWidgetFactory(
-                name_label_text="Update rate",
-                decimals=1,
-                limits=(1, None),
-            ),
-        }
+        distance_pidget_mapping = dict(DistanceViewPlugin.get_pidget_mapping())
+
+        # Bilateration requires an update rate, so replace the optional float with a mandatory
+        distance_pidget_mapping["update_rate"] = pidgets.FloatParameterWidgetFactory(
+            name_label_text="Update rate",
+            decimals=1,
+            limits=(1, None),
+        )
+        return distance_pidget_mapping
 
     def on_app_model_update(self, app_model: AppModel) -> None:
         state = app_model.backend_plugin_state
-        self.two_sensor_id_editor.update_available_sensor_list(app_model._a121_server_info)
 
         if state is None:
             self.start_button.setEnabled(False)
@@ -659,7 +583,7 @@ class ViewPlugin(DetectorViewPluginBase):
             self.config_editor.setEnabled(False)
             self.bilateration_config_editor.set_data(None)
             self.bilateration_config_editor.setEnabled(False)
-            self.two_sensor_id_editor.set_data(None)
+            self.two_sensor_id_editor.set_selected_sensors(None, [])
             self.message_box.setText("")
 
             return
@@ -674,7 +598,9 @@ class ViewPlugin(DetectorViewPluginBase):
             app_model.plugin_state == PluginState.LOADED_IDLE
         )
         self.bilateration_config_editor.set_data(state.bilateration_config)
-        self.two_sensor_id_editor.set_data(state.sensor_ids)
+        self.two_sensor_id_editor.set_selected_sensors(
+            state.sensor_ids, app_model.connected_sensors
+        )
         self.two_sensor_id_editor.setEnabled(app_model.plugin_state.is_steady)
 
         detector_status = Detector.get_detector_status(
@@ -694,7 +620,6 @@ class ViewPlugin(DetectorViewPluginBase):
         self.start_button.setEnabled(ready_for_session and detector_status.ready_to_start)
         self.stop_button.setEnabled(app_model.plugin_state == PluginState.LOADED_BUSY)
 
-    # TODO: move to detector base (?)
     def _on_config_update(self, config: DetectorConfig) -> None:
         self.app_model.put_backend_plugin_task("update_config", {"config": config})
 
@@ -704,27 +629,15 @@ class ViewPlugin(DetectorViewPluginBase):
     def _on_sensor_ids_update(self, sensor_ids: list[int]) -> None:
         self.app_model.put_backend_plugin_task("update_sensor_ids", {"sensor_ids": sensor_ids})
 
-    # TODO: move to detector base (?)
     def handle_message(self, message: GeneralMessage) -> None:
         if message.name == "sync":
             log.debug(f"{type(self).__name__} syncing")
 
             self.config_editor.sync()
             self.bilateration_config_editor.sync()
-            self.two_sensor_id_editor.sync()
         else:
             raise RuntimeError("Unknown message")
 
-    # TODO: move to detector base (?)
-    def _send_start_request(self) -> None:
-        self.app_model.put_backend_plugin_task("start_session", on_error=self.app_model.emit_error)
-        self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
-
-    # TODO: move to detector base (?)
-    def _send_stop_request(self) -> None:
-        self.app_model.put_backend_plugin_task("stop_session", on_error=self.app_model.emit_error)
-        self.app_model.set_plugin_state(PluginState.LOADED_STOPPING)
-
     def _on_calibrate_detector(self) -> None:
         self.app_model.put_backend_plugin_task("calibrate_detector")
         self.app_model.set_plugin_state(PluginState.LOADED_STARTING)
