@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from __future__ import annotations
@@ -20,7 +20,6 @@ import pyqtgraph as pg
 import acconeer.exptool as et
 from acconeer.exptool import a121
 from acconeer.exptool.a121._h5_utils import _create_h5_string_dataset
-from acconeer.exptool.a121.algo._base import AlgoBase
 from acconeer.exptool.a121.algo._plugins import (
     DetectorBackendPluginBase,
     DetectorPlotPluginBase,
@@ -49,16 +48,10 @@ from acconeer.exptool.app.new import (
 from ._detector import Detector, DetectorConfig, DetectorResult, _load_algo_data
 
 
-@attrs.mutable(kw_only=True)
-class PlotConfig(AlgoBase):
-    number_of_zones: Optional[int] = attrs.field(default=None)
-
-
 @attrs.mutable(kw_only=True)
 class SharedState:
     sensor_id: int = attrs.field(default=1)
     config: DetectorConfig = attrs.field(factory=DetectorConfig)
-    plot_config: PlotConfig = attrs.field(factory=PlotConfig)
 
 
 class PluginPresetId(Enum):
@@ -84,7 +77,6 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
     def _load_from_cache(self, file: h5py.File) -> None:
         self.shared_state.config = DetectorConfig.from_json(file["config"][()])
-        self.shared_state.plot_config = PlotConfig.from_json(file["plot_config"][()])
 
     @is_task
     def restore_defaults(self) -> None:
@@ -96,11 +88,6 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
         self.shared_state.sensor_id = sensor_id
         self.broadcast(sync=True)
 
-    @is_task
-    def update_plot_config(self, *, config: PlotConfig) -> None:
-        self.shared_state.plot_config = config
-        self.broadcast(sync=True)
-
     def _sync_sensor_ids(self) -> None:
         if self.client is not None:
             sensor_ids = self.client.server_info.connected_sensors
@@ -115,7 +102,6 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
 
     def save_to_cache(self, file: h5py.File) -> None:
         _create_h5_string_dataset(file, "config", self.shared_state.config.to_json())
-        _create_h5_string_dataset(file, "plot_config", self.shared_state.plot_config.to_json())
 
     @is_task
     def set_preset(self, preset_id: int) -> None:
@@ -143,7 +129,7 @@ class BackendPlugin(DetectorBackendPluginBase[SharedState]):
                 kwargs=dict(
                     detector_config=self.shared_state.config,
                     sensor_config=Detector._get_sensor_config(self.shared_state.config),
-                    plot_config=self.shared_state.plot_config,
+                    estimated_frame_rate=self._detector_instance.estimated_frame_rate,
                 ),
                 recipient="plot_plugin",
             )
@@ -183,24 +169,18 @@ class PlotPlugin(DetectorPlotPluginBase):
         self,
         detector_config: DetectorConfig,
         sensor_config: a121.SensorConfig,
-        plot_config: PlotConfig,
+        estimated_frame_rate: float,
     ) -> None:
         self.detector_config = detector_config
         self.distances = np.linspace(
             detector_config.start_m, detector_config.end_m, sensor_config.num_points
         )
 
-        self.history_length_s = 10
+        self.history_length_s = 5
+        self.history_length_n = int(round(self.history_length_s * estimated_frame_rate))
+        self.intra_history = np.zeros(self.history_length_n)
+        self.inter_history = np.zeros(self.history_length_n)
 
-        if plot_config.number_of_zones:
-            self.num_sectors = min(plot_config.number_of_zones, self.distances.size)
-            self.sector_size = max(1, -(-self.distances.size // self.num_sectors))
-        else:
-            max_num_of_sectors = max(6, self.distances.size // 3)
-            self.sector_size = max(1, -(-self.distances.size // max_num_of_sectors))
-            self.num_sectors = -(-self.distances.size // self.sector_size)
-
-        self.sector_offset = (self.num_sectors * self.sector_size - self.distances.size) // 2
         win = self.plot_layout
 
         self.intra_limit_lines = []
@@ -342,30 +322,9 @@ class PlotPlugin(DetectorPlotPluginBase):
         for line in self.inter_limit_lines:
             line.setPos(self.detector_config.inter_detection_threshold)
 
-        # Sector plot
-
-        self.sector_plot = pg.PlotItem()
-        self.sector_plot.setAspectLocked()
-        self.sector_plot.hideAxis("left")
-        self.sector_plot.hideAxis("bottom")
-        self.sectors = []
-
-        pen = pg.mkPen("k", width=1)
-        span_deg = 25
-        for r in np.flip(np.arange(self.num_sectors) + 1):
-            sector = pg.QtWidgets.QGraphicsEllipseItem(-r, -r, r * 2, r * 2)
-            sector.setStartAngle(-16 * span_deg)
-            sector.setSpanAngle(16 * span_deg * 2)
-            sector.setPen(pen)
-            self.sector_plot.addItem(sector)
-            self.sectors.append(sector)
-
-        self.sectors.reverse()
-
         sublayout = win.addLayout(row=2, col=0, colspan=2)
         sublayout.layout.setColumnStretchFactor(0, 2)
         sublayout.addItem(self.move_plot, row=0, col=0)
-        sublayout.addItem(self.sector_plot, row=0, col=1)
 
     def update(self, data: DetectorResult) -> None:
         noise = data.processor_extra_result.lp_noise
@@ -374,12 +333,10 @@ class PlotPlugin(DetectorPlotPluginBase):
 
         movement_x = data.presence_distance
 
-        self.inter_curve.setData(self.distances, data.processor_extra_result.inter)
-        self.intra_curve.setData(self.distances, data.processor_extra_result.intra)
+        self.inter_curve.setData(self.distances, data.inter_depthwise_scores)
+        self.intra_curve.setData(self.distances, data.intra_depthwise_scores)
         m = self.move_smooth_max.update(
-            np.max(
-                np.maximum(data.processor_extra_result.inter, data.processor_extra_result.intra)
-            )
+            np.max(np.maximum(data.inter_depthwise_scores, data.intra_depthwise_scores))
         )
         m = max(
             m,
@@ -408,41 +365,33 @@ class PlotPlugin(DetectorPlotPluginBase):
 
         # Intra presence
 
-        move_hist_ys = data.processor_extra_result.intra_presence_history
-        move_hist_xs = np.linspace(-self.history_length_s, 0, len(move_hist_ys))
+        move_hist_xs = np.linspace(-self.history_length_s, 0, self.history_length_n)
+
+        self.intra_history = np.roll(self.intra_history, -1)
+        self.intra_history[-1] = data.intra_presence_score
 
         m_hist = max(
-            float(np.max(move_hist_ys)), self.detector_config.intra_detection_threshold * 1.05
+            float(np.max(self.intra_history)),
+            self.detector_config.intra_detection_threshold * 1.05,
         )
         m_hist = self.intra_history_smooth_max.update(m_hist)
 
         self.intra_hist_plot.setYRange(0, m_hist)
-        self.intra_hist_curve.setData(move_hist_xs, move_hist_ys)
+        self.intra_hist_curve.setData(move_hist_xs, self.intra_history)
 
         # Inter presence
 
-        move_hist_ys = data.processor_extra_result.inter_presence_history
-        move_hist_xs = np.linspace(-self.history_length_s, 0, len(move_hist_ys))
+        self.inter_history = np.roll(self.inter_history, -1)
+        self.inter_history[-1] = data.inter_presence_score
 
         m_hist = max(
-            float(np.max(move_hist_ys)), self.detector_config.inter_detection_threshold * 1.05
+            float(np.max(self.inter_history)),
+            self.detector_config.inter_detection_threshold * 1.05,
         )
         m_hist = self.inter_history_smooth_max.update(m_hist)
 
         self.inter_hist_plot.setYRange(0, m_hist)
-        self.inter_hist_curve.setData(move_hist_xs, move_hist_ys)
-
-        # Sector
-
-        brush = et.utils.pg_brush_cycler(0)
-        for sector in self.sectors:
-            sector.setBrush(brush)
-
-        if data.presence_detected:
-            index = (
-                data.processor_extra_result.presence_distance_index + self.sector_offset
-            ) // self.sector_size
-            self.sectors[index].setBrush(et.utils.pg_brush_cycler(1))
+        self.inter_hist_curve.setData(move_hist_xs, self.inter_history)
 
     def set_present_text_y_pos(self, y: float) -> None:
         x_pos = self.distances[0] + (self.distances[-1] - self.distances[0]) / 2
@@ -511,21 +460,6 @@ class ViewPlugin(DetectorViewPluginBase):
         self.config_editor.sig_update.connect(self._on_config_update)
         scrolly_layout.addWidget(self.config_editor)
 
-        self.plot_config_editor = AttrsConfigEditor[PlotConfig](
-            title="Plot parameters",
-            factory_mapping={
-                "number_of_zones": pidgets.OptionalIntParameterWidgetFactory(
-                    name_label_text="Detection zones",
-                    checkbox_label_text="Override",
-                    limits=(1, 10),
-                    init_set_value=3,
-                )
-            },
-            parent=self.scrolly_widget,
-        )
-        self.plot_config_editor.sig_update.connect(self._on_plot_config_update)
-        scrolly_layout.addWidget(self.plot_config_editor)
-
         self.sticky_widget.setLayout(sticky_layout)
         self.scrolly_widget.setLayout(scrolly_layout)
 
@@ -672,8 +606,6 @@ class ViewPlugin(DetectorViewPluginBase):
 
             self.config_editor.set_data(None)
             self.config_editor.setEnabled(False)
-            self.plot_config_editor.set_data(None)
-            self.plot_config_editor.setEnabled(False)
             self.sensor_id_pidget.set_selected_sensor(None, [])
 
             return
@@ -684,8 +616,6 @@ class ViewPlugin(DetectorViewPluginBase):
 
         self.config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
         self.config_editor.set_data(state.config)
-        self.plot_config_editor.setEnabled(app_model.plugin_state == PluginState.LOADED_IDLE)
-        self.plot_config_editor.set_data(state.plot_config)
         self.sensor_id_pidget.set_selected_sensor(state.sensor_id, app_model.connected_sensors)
         self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
@@ -695,9 +625,6 @@ class ViewPlugin(DetectorViewPluginBase):
     def _on_config_update(self, config: DetectorConfig) -> None:
         self.app_model.put_backend_plugin_task("update_config", {"config": config})
 
-    def _on_plot_config_update(self, config: PlotConfig) -> None:
-        self.app_model.put_backend_plugin_task("update_plot_config", {"config": config})
-
     def handle_message(self, message: GeneralMessage) -> None:
         if message.name == "sync":
             self._log.debug(f"{type(self).__name__} syncing")
