@@ -1,11 +1,13 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from . import pidgets
 from .attrs_config_editor import AttrsConfigEditor
+from .collapsible_widget import CollapsibleWidget
 from .metadata_view import ExtendedMetadataView, MetadataView, SmartMetadataView
 from .misc_error_view import MiscErrorView
 from .perf_calc_view import ExtendedPerfCalcView, PerfCalcView, SmartPerfCalcView
+from .sensor_config_editor import SensorConfigEditor
 from .session_config_editor import SessionConfigEditor
 from .two_sensor_ids_editor import TwoSensorIdsEditor
 from .types import PidgetFactoryMapping
