@@ -25,7 +25,6 @@ from PySide6.QtWidgets import (
     QWidget,
 )
 
-from acconeer.exptool import a121
 from acconeer.exptool.a121._core.entities import Criticality
 
 
@@ -466,18 +465,22 @@ class ComboboxParameterWidget(ParameterWidget, Generic[T]):
 
 
 @attrs.frozen(kw_only=True, slots=False)
-class UpdateableComboboxParameterWidgetFactory(ComboboxParameterWidgetFactory[T]):
-    def create(self, parent: QWidget) -> UpdateableComboboxParameterWidget[T]:
-        return UpdateableComboboxParameterWidget(self, parent)
+class SensorIdParameterWidgetFactory(ComboboxParameterWidgetFactory[int]):
+    name_label_text: str = attrs.field(default="Sensor:")
+    name_label_tooltip: str = attrs.field(default="The sensor to use in session")
+
+    def create(self, parent: QWidget) -> SensorIdParameterWidget:
+        return SensorIdParameterWidget(self, parent)
 
 
-class UpdateableComboboxParameterWidget(ComboboxParameterWidget[T]):
-    def __init__(
-        self, factory: UpdateableComboboxParameterWidgetFactory[T], parent: QWidget
-    ) -> None:
+class SensorIdParameterWidget(ComboboxParameterWidget[int]):
+    _sensor_list: list[int]
+
+    def __init__(self, factory: SensorIdParameterWidgetFactory, parent: QWidget) -> None:
         super().__init__(factory, parent)
+        self._sensor_list = []
 
-    def update_items(self, items: list[tuple[str, T]]) -> None:
+    def _update_items(self, items: list[tuple[str, int]]) -> None:
         with QtCore.QSignalBlocker(
             self
         ):  # Does not take into account when selected item is removed
@@ -486,44 +489,19 @@ class UpdateableComboboxParameterWidget(ComboboxParameterWidget[T]):
             for displayed_text, user_data in items:
                 self._combobox.addItem(displayed_text, user_data)
 
-    def set_parameter(self, param: Any) -> None:
+    def set_selected_sensor(self, sensor_id: Optional[int], sensor_list: list[int]) -> None:
+        if sensor_list != self._sensor_list:
+            self._sensor_list = sensor_list
+            self._update_items([(str(i), i) for i in sensor_list])
+
         try:
-            super().set_parameter(param)
+            super().set_parameter(sensor_id)
         except ValueError:
             self.setEnabled(False)
         else:
             self.setEnabled(True)
 
 
-@attrs.frozen(kw_only=True, slots=False)
-class SensorIdParameterWidgetFactory(UpdateableComboboxParameterWidgetFactory[int]):
-    name_label_text: str = attrs.field(default="Sensor:")
-
-    def create(self, parent: QWidget) -> SensorIdParameterWidget:
-        return SensorIdParameterWidget(self, parent)
-
-
-class SensorIdParameterWidget(UpdateableComboboxParameterWidget[int]):
-    _server_info: Optional[a121.ServerInfo]
-
-    def __init__(self, factory: SensorIdParameterWidgetFactory, parent: QWidget) -> None:
-        super().__init__(factory, parent)
-        self._server_info = None
-
-    def update_available_sensor_list(self, server_info: Optional[a121.ServerInfo]) -> None:
-        if server_info == self._server_info:
-            return
-
-        self._server_info = server_info
-
-        if server_info is None:
-            self.update_items([])
-            self.setEnabled(False)
-        else:
-            self.update_items([(str(i), i) for i in server_info.connected_sensors])
-            self.setEnabled(True)
-
-
 @attrs.frozen(kw_only=True, slots=False)
 class EnumParameterWidgetFactory(ComboboxParameterWidgetFactory[EnumT]):
     enum_type: Type[EnumT] = attrs.field()
