@@ -1,9 +1,8 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from acconeer.exptool.flash._stm32uart import ACCONEER_XM_CP2105_MODULE_PID, Stm32UartFlasher
 from acconeer.exptool.flash._xc120 import (
-    ACCONEER_XC120_BOARD_PROTOCOL_PID,
     ACCONEER_XC120_BOOTLOADER_PID,
     ACCONEER_XC120_EXPLORATION_SERVER_PID,
     ACCONEER_XC120_EXPLORATION_SERVER_WINUSB_PID,
@@ -12,7 +11,6 @@ from acconeer.exptool.flash._xc120 import (
 
 
 PRODUCT_PID_TO_FLASH_MAP = {
-    ACCONEER_XC120_BOARD_PROTOCOL_PID: BootloaderTool,
     ACCONEER_XC120_BOOTLOADER_PID: BootloaderTool,
     ACCONEER_XC120_EXPLORATION_SERVER_PID: BootloaderTool,
     ACCONEER_XC120_EXPLORATION_SERVER_WINUSB_PID: BootloaderTool,
