@@ -1,4 +1,4 @@
-# Copyright (c) Acconeer AB, 2022
+# Copyright (c) Acconeer AB, 2022-2023
 # All rights reserved
 
 from __future__ import annotations
@@ -13,6 +13,7 @@ import struct
 import sys
 import time
 from datetime import datetime
+from types import ModuleType
 from typing import Any, List, Optional
 
 import attrs
@@ -118,6 +119,7 @@ _USB_IDS = [  # (vid, pid, 'model number', 'Unflashed')
     (0x0483, 0xA42C, "XC120", True),
     (0x0483, 0xA42D, "XC120", False),
     (0x0483, 0xA449, "XC120", False),
+    (0xACC0, 0xE121, "XV12X", False),
 ]
 
 
@@ -408,6 +410,13 @@ def get_usb_device_by_serial(serial, only_accessible=False):
     raise ValueError(f"Could not find usb device with serial number '{serial}'")
 
 
+def get_module_version(module: ModuleType) -> str:
+    if hasattr(module, "__version__"):
+        return str(module.__version__)
+    else:
+        raise AttributeError(f"Unknown module version for {module.__name__}")
+
+
 def color_cycler(i=0):
     category10 = [
         "#1f77b4",
